summaryrefslogtreecommitdiff
path: root/src/common/md5calc.hpp
diff options
context:
space:
mode:
authorBen Longbons <b.r.longbons@gmail.com>2013-09-08 19:43:28 -0700
committerBen Longbons <b.r.longbons@gmail.com>2013-09-09 19:29:31 -0700
commita5861a4c81bb616b7fba2028cf9ee31f890357c5 (patch)
tree0a7aedad97d70b6194eb57a7de39857d015685a3 /src/common/md5calc.hpp
parent367e76ba89bde0e3fb6c4ae0e64cd3927e0db2f2 (diff)
downloadtmwa-a5861a4c81bb616b7fba2028cf9ee31f890357c5.tar.gz
tmwa-a5861a4c81bb616b7fba2028cf9ee31f890357c5.tar.bz2
tmwa-a5861a4c81bb616b7fba2028cf9ee31f890357c5.tar.xz
tmwa-a5861a4c81bb616b7fba2028cf9ee31f890357c5.zip
Use IP4 classes and rename conf variables
Diffstat (limited to 'src/common/md5calc.hpp')
-rw-r--r--src/common/md5calc.hpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/common/md5calc.hpp b/src/common/md5calc.hpp
index 98f44d6..70a996e 100644
--- a/src/common/md5calc.hpp
+++ b/src/common/md5calc.hpp
@@ -11,6 +11,7 @@
#include <array>
+#include "ip.hpp"
#include "mmo.hpp"
#include "strings.hpp"
@@ -53,7 +54,7 @@ SaltString make_salt(void);
/// check plaintext password against saved saltcrypt
bool pass_ok(AccountPass password, AccountCrypt crypted);
-/// This returns an in_addr because it is configurable whether it gets called at all
-struct in_addr MD5_ip(struct in_addr ip);
+/// This returns an IP4Address because it is configurable whether it gets called at all
+IP4Address MD5_ip(IP4Address ip);
#endif // MD5CALC_HPP